@@ -7,8 +7,8 @@ from functools import wraps
 
 import click
 
-from .cve_api import CveApi, CveApiError
 from . import __version__
+from .cve_api import CveApi, CveApiError
 
 CVE_RE = re.compile(r"^CVE-[12]\d{3}-\d{4,}$")
 CONTEXT_SETTINGS = {
@@ -75,9 +75,9 @@ def print_user(user):
         click.echo(f"{name} — ", nl=False)
     click.echo(user["username"])
 
-    # If this is a newly created user, print out the API token.
+    # If this is a newly created user, print out the API key.
     if "secret" in user:
-        click.echo(f"├─ API token:\t{user['secret']}")
+        click.echo(f"├─ API key:\t{user['secret']}")
 
     click.echo(f"├─ Active:\t{bool_to_text(user['active'])}")
     click.echo(f"├─ Roles:\t{', '.join(user['authority']['active_roles']) or 'None'}")
@@ -161,13 +161,15 @@ class Config:
     envvar="CVE_API_KEY",
     required=True,
     help="Your API key (env var: CVE_API_KEY)",
+    prompt="API key",
+    hide_input=True,
 )
 @click.option(
     "-e",
     "--env",
     envvar="CVE_ENVIRONMENT",
     default="prod",
-    type=click.Choice(["prod", "dev"]),
+    type=click.Choice(CveApi.ENVS.keys()),
     help="Select deployment environment to query (env var: CVE_ENVIRONMENT)",
 )
 @click.option(
@@ -352,7 +354,7 @@ def quota(ctx, print_raw):
 
     click.echo("CNA quota for ", nl=False)
     click.secho(f"{ctx.obj.org}", bold=True, nl=False)
-    click.echo(f":")
+    click.echo(":")
     click.echo(f"├─ Limit:\t{cve_quota['id_quota']}")
     click.echo(f"├─ Reserved:\t{cve_quota['total_reserved']}")
     click.echo(f"└─ Available:\t{cve_quota['available']}")
@@ -388,31 +390,31 @@ def show_user(ctx, username, print_raw):
 @click.option(
     "-u",
     "--username",
-    help="User whose API token should be reset (only ADMIN role users can update other users).",
+    help="User whose API key should be reset (only ADMIN role users can update other users).",
     show_default="Current user specified in global -u/--username/CVE_USER",
 )
 @click.option("--raw", "print_raw", default=False, is_flag=True, help="Print response JSON.")
 @click.pass_context
 @handle_cve_api_error
-def reset_token(ctx, username, print_raw):
-    """Reset a user's personal access token (API token).
+def reset_key(ctx, username, print_raw):
+    """Reset a user's personal access token (API key).
 
-    This token is used to authenticate each request to the CVE API.
+    This API key is used to authenticate each request to the CVE API.
     """
     cve_api = ctx.obj.cve_api
     if not username:
         username = cve_api.username
 
-    api_key = cve_api.reset_api_token(username)
+    api_key = cve_api.reset_api_key(username)
     if print_raw:
         print_json_data(api_key)
         return
 
-    click.echo(f"New API token for ", nl=False)
+    click.echo("New API key for ", nl=False)
     click.secho(username, bold=True, nl=False)
     click.echo(":\n")
     click.secho(api_key["API-secret"], bold=True)
-    click.echo("\nMake sure to copy your new API token; you won't be able to access it again!")
+    click.echo("\nMake sure to copy your new API key; you won't be able to access it again!")
 
 
 @show_user.command(name="update")
@@ -436,7 +438,7 @@ def reset_token(ctx, username, print_raw):
 def update_user(ctx, username, **opts_data):
     """Update a user.
 
-    To reset a user's API token, use `cve user reset-token`.
+    To reset a user's API key, use `cve user reset-key`.
     """
     print_raw = opts_data.pop("print_raw")
     cve_api = ctx.obj.cve_api
@@ -478,7 +480,7 @@ def update_user(ctx, username, **opts_data):
 
 
 @show_user.command(name="create")
-@click.option("-u", "--username", default="", required=True, help="Set username.")
+@click.option("-u", "--username", required=True, help="Set username.")
 @click.option("--name-first", default="", help="Set first name.")
 @click.option("--name-last", default="", help="Set last name.")
 @click.option(
@@ -496,9 +498,7 @@ def create_user(ctx, username, name_first, name_last, roles, print_raw):
     users when you really need them.
     """
     user_data = defaultdict(dict)
-
-    if username:
-        user_data["username"] = username
+    user_data["username"] = username
 
     if name_first:
         user_data["name"]["first"] = name_first
@@ -512,11 +512,11 @@ def create_user(ctx, username, name_first, name_last, roles, print_raw):
     if ctx.obj.interactive:
         click.echo("You are about to create the following user under your ", nl=False)
         click.secho(ctx.obj.org, bold=True, nl=False)
-        click.echo(f" org:\n\nUsername:\t", nl=False)
+        click.echo(" org:\n\nUsername:\t", nl=False)
         click.secho(username, bold=True)
         click.echo("Full name:\t", nl=False)
         click.secho(name_first + name_last or "None", bold=True)
-        click.echo(f"Roles:\t\t", nl=False)
+        click.echo("Roles:\t\t", nl=False)
         click.secho(", ".join(roles) or "None", bold=True)
         click.echo("\nThis action cannot be undone; created users can only be marked as inactive.")
         if not click.confirm("Do you want to continue?"):
@@ -532,7 +532,7 @@ def create_user(ctx, username, name_first, name_last, roles, print_raw):
 
     click.echo("Created user:\n")
     print_user(created_user)
-    click.echo("\nMake sure to copy the returned API token; you won't be able to access it again!")
+    click.echo("\nMake sure to copy the returned API key; you won't be able to access it again!")
 
 
 @cli.group(name="org", invoke_without_command=True)
@@ -595,7 +595,7 @@ def ping(ctx):
 
     click.echo(f"CVE API Status — {cve_api.url}\n└─ ", nl=False)
     if ok:
-        click.secho(f"OK", fg="green")
+        click.secho("OK", fg="green")
     else:
         click.secho("ERROR:", bold=True, nl=False)
         click.echo(f" {error_msg}")
